/* global Bdf,$$ */
/**
 * Objet global définissant l'espace de nom Ficheform
 * 
 * @namespace Ficheframe,Bdf
 */
var Ficheframe = {};

Ficheframe.testToolbar = function (contentWindow, toolbarId, editTarget, tocTarget) {
    _showToolbar(false);
    var buttonId = "ficheframe_button_ficheedit";
    var pathName;
    try {
        pathName = contentWindow.location.pathname;
    } catch(error) {
        return;
    }
    if (!pathName.startsWith(_getFichothequeRoot())) {
        return;
    }
    var ficheTest = pathName.match(/\/fiches\/([a-z][a-z0-9]*)-([0-9]+)(-[_a-z0-9]+)?\.html$/);
    if (!ficheTest) {
        return;
    }
    var corpusName = ficheTest[1];
    var ficheId = ficheTest[2];
    Bdf.api.loadFiche({
        corpus: corpusName,
        id: ficheId,
        callback: function (data) {
            if (data.fiche) {
                let editable = data.fiche.editable;
                let toc = _checkToc( contentWindow.document);
                let html = Bdf.render("ficheframe:toolbar", {
                    path: pathName,
                    corpusName: corpusName,
                    ficheId: ficheId,
                    editable: editable,
                    toc: toc,
                    editTarget: editTarget,
                    tocTarget: tocTarget
                });
                $$(toolbarId).html(html);
                if (html.length > 0) {
                    _showToolbar(true);
                    $(contentWindow).on('pagehide', function(e) {
                        _showToolbar(false);
                    });
                    let editLink = $$.one(buttonId);
                    let originalHref = editLink.href;
                    let components = $$(contentWindow.document, {bdfComponent: true});
                    $(contentWindow).on("scroll", function(){
                        let scrollTop = $(contentWindow.document).scrollTop();
                        let currentComponent = false;
                        for (let i = components.length-1; i >= 0; i--) {
                            let component = components[i];
                            if (scrollTop > $(component).offset().top - 75) {
                                currentComponent = component;
                                break;
                            }
                        }
                        if (currentComponent) {
                            let goto = currentComponent.dataset.bdfComponent;
                            if (goto === "satellite") {
                                goto = goto + "_" + currentComponent.dataset.bdfSatellite;
                            } else {
                                let $satellite = $(currentComponent).parents($$.toCssSelector({bdfComponent: "satellite"}));
                                if ($satellite.length > 0) {
                                    goto = "satellite_" + $satellite[0].dataset.bdfSatellite + "/" + goto;
                                }
                            }
                            editLink.href = originalHref + "&goto=" + goto;
                        } else {
                            editLink.href = originalHref;
                        }
                    });
                }
            }
        }
    });
    
    function _showToolbar(display) {
        Ficheframe.showToolbar(toolbarId,display);
    }
    
    function _checkToc(document) {
        let array = new Array();
        $(document).find("h2, section > h1").each(function (index, element) {
            let id = element.id;
            if (!id) {
                id = Bdf.generateId();
                element.id = id;
            }
            let $element = $(element);
            let text = $element.text();
            if (!$element.is(":hidden")) {
                array.push({
                    id: id,
                    text: text
                });
            }
        });
        return array;
    }
    
    function _getFichothequeRoot() {
        let currentPathName = window.location.pathname;
        let lastIndex = currentPathName.lastIndexOf("/");
        return currentPathName.substr(0, lastIndex + 1);
    }
};

Ficheframe.showToolbar = function (toolbarId, display) {
    if (display) {
        $$(toolbarId).removeClass("hidden");
    } else {
        $$(toolbarId).addClass("hidden");
    }
};
